@@ -29,7 +29,6 @@
 
 #include <libkleo_debug.h>
 
-#include <KConfigGroup>
 #include <KSharedConfig>
 
 #include <QGpgME/CryptoConfig>
@@ -1489,6 +1488,12 @@ Error KeyCache::RefreshKeysJob::Private::startKeyListing(GpgME::Protocol proto)
     if (!job) {
         return Error();
     }
+#ifdef QGPGME_LISTALLKEYSJOB_HAS_OPTIONS
+    if (!m_cache->initialized()) {
+        // avoid delays during the initial key listing
+        job->setOptions(QGpgME::ListAllKeysJob::DisableAutomaticTrustDatabaseCheck);
+    }
+#endif
 
 #if 0
     aheinecke: 2017.01.12:
@@ -1606,7 +1611,7 @@ GpgME::Key KeyCache::findBestByMailBox(const char *addr, GpgME::Protocol proto,
 
     // support lookup of email addresses enclosed in angle brackets
     QByteArray address(addr);
-    if (address[0] == '<' && address[address.size() - 1] == '>') {
+    if (address.size() > 1 && address[0] == '<' && address[address.size() - 1] == '>') {
         address = address.mid(1, address.size() - 2);
     }
     address = address.toLower();
